#
# spec file for package yast2-ldap
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-ldap
Version:        5.0.0
Release:        1.5

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2

Group:          System/YaST
License:        GPL-2.0-only
BuildRequires:  gcc-c++
BuildRequires:  libldapcpp-devel
BuildRequires:  libtool
BuildRequires:  yast2
BuildRequires:  yast2-core-devel
BuildRequires:  yast2-devtools >= 3.1.10
Summary:        YaST2 - LDAP Agent
Requires:       ldapcpplib
Requires:       yast2
Requires:       yast2-network
Conflicts:      yast2-auth-client < 3.1.6
Conflicts:      yast2-ldap-client < 3.1.5

%description
This agent is used by various YaST2 modules to work with LDAP. It
enables searching the LDAP tree and adding/deleting/modifying items on
an LDAP server.

%prep
%setup -n %{name}-%{version}

%build
%yast_build

%install
%yast_install

%files
%defattr(-,root,root)
%{yast_moduledir}/*
%{yast_clientdir}/*
%{yast_scrconfdir}/*.scr
%dir %{yast_yncludedir}/ldap/
%{yast_yncludedir}/ldap/*
%{yast_plugindir}/libpy2ag_ldap.so.*
%{yast_plugindir}/libpy2ag_ldap.so
%{yast_plugindir}/libpy2ag_ldap.la
%doc %{yast_docdir}
%license COPYING

%changelog
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Wed Apr 21 2021 José Iván López González <jlopez@suse.com>
- Use the given BindDN to connect to the LDAP database.
- bsc#1185054
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0
* Tue Feb 26 2019 José Iván López González <jlopez@suse.com>
- Version bump (bsc#1124009)
- 4.1.0
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Fri Apr  6 2018 mfilka@suse.com
- bnc#1087957 - version bump
- 4.0.0
* Tue Sep 20 2016 jreidinger@suse.com
- disable doc generation (FATE#320356)
- remove unnecessary build dependency to speed up build
  (bsc#999203)
- 3.1.14
* Thu Sep 25 2014 varkoly@suse.com
- bnc#897997 YaST2 User authentication not enumerating LDAP options
- 3.1.13
* Tue Aug  5 2014 varkoly@suse.com
- Set member_attribute to 'member'. We only use rfc2307bis.schema
- bnc#889556 - yast2 users can not create ldap groups
- 3.1.12
* Tue Jul  1 2014 ckornacker@suse.com
- don't call deprecated methods in ldap_browser (bnc#885227)
- 3.1.11
* Wed Jun 11 2014 varkoly@suse.com
- Do not add MenuButton to ButtonBox
- 3.1.10
* Wed Mar 26 2014 varkoly@suse.com
- Remove some not used variables and functions
- 3.1.9
* Thu Mar 20 2014 varkoly@suse.com
- bnc#865812 - can't configure ldap login
- 3.1.8
* Wed Mar 12 2014 varkoly@suse.com
- ldap.conf is not case sensitive
- @ldap_tls is a string not a boolean
- code clean up. Remove not used variables
- 3.1.7
* Thu Feb 13 2014 varkoly@suse.com
- Fix SCR.Reads and Writes first parameter. This must be path.
* Thu Feb 13 2014 varkoly@suse.com
- Remove not used subroutines from the Ldap module
- BNC#863329 - Missing Ldap::Export()
- BNC#863612 YaST reports Cannot find client ldap/routines.rb
- Simplify ldap-conf agent: Until now ldap informations was saved in
  3 places: /etc/ldap.conf /etc/openldap/ldap.conf and the sysconfig
  file ldap. From now on only /etc/openldap/ldap.conf will be used.
  /etc/ldap.conf is only for nss_ldap which is not provided anymore
  The variable BIND_DN in sysconfig file ldap can saved in
  /etc/openldap/ldap.conf too. BASE_CONFIG_DN was everytime
  ou=ldapconfig,$BASE
- 3.1.6
* Tue Feb 11 2014 jreidinger@suse.com
- add missing sysconfig ldap agent
- 3.1.5
* Tue Feb  4 2014 jreidinger@suse.com
- properly conflict with old yast2-ldap-client
- 3.1.4
* Fri Jan 31 2014 varkoly@suse.com
- Include routines from routines.rb into Ldap.rb
- 3.1.3
* Fri Jan 31 2014 varkoly@suse.com
- Add yast2-network is needed by Ldap.rb
* Fri Jan 31 2014 varkoly@suse.com
- Increase version to mark that this package provides the
  yast2-ldap-client functionality for other yast modules
* Wed Jan 29 2014 varkoly@suse.com
- Include modules from yast2-ldap-client
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Tue Aug 13 2013 lslezak@suse.cz
- fixed build with yast2-devtools >= 3.0.3
- 3.0.1
* Tue Jul 30 2013 yast-devel@opensuse.org
- version 3.0.0
* Fri Feb  1 2013 jsuchome@suse.cz
- catch the possible exception from TLS options calls (bnc#801065)
- 2.23.0
* Mon Mar 26 2012 jsuchome@suse.cz
- removed libxcrypt-devel from buildrequires
- 2.22.2
* Mon Feb 20 2012 jsuchome@suse.cz
- added option to disable certificate checks (bnc#745877)
- 2.22.1
* Tue Jan 24 2012 jsuchome@suse.cz
- confirmed license
- 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Aug 31 2011 jsuchome@suse.cz
- properly initialize value of ldap_initialized (bnc#710430)
- 2.21.1
* Mon Apr  4 2011 jsuchome@suse.cz
- use the global TLS Options if present (bnc#684395)
- 2.21.0
* Fri Feb  4 2011 jsuchome@suse.cz
- added command to close the connection
- 2.20.1
* Thu Jan 13 2011 jsuchome@suse.cz
- added support for setting TLS options
- 2.20.0
* Thu Jun 18 2009 mvidner@suse.cz
- Using autodocs-cc.ami, which contains a fix for automake 1.11.
* Wed Sep  3 2008 jsuchome@suse.cz
- LdapServerAccess.pm: adapted to new LdapServer API
  (rhafer, bnc#422523)
- 2.17.3
* Wed Aug  6 2008 jsuchome@suse.cz
- adapted LdapServerAccess to new API of yast2-ldap-server (rhafer)
- 2.17.2
* Fri Jul 18 2008 jsuchome@suse.cz
- do not lowercase LDAP object names (fate#303596)
- 2.17.1
* Tue Jun 24 2008 jsuchome@suse.cz
- ldapcpplib-devel renamed to libldapcpp-devel (bnc#403082)
- 2.17.0
* Fri Feb 29 2008 jsuchome@suse.cz
- document Execute (.unbind) agent call
* Wed Feb 27 2008 jsuchome@suse.cz
- search for all attributes (this time pwdaccountlockedtime)
  before modify action (bnc#364837)
- 2.16.0
* Mon Mar  5 2007 jsuchome@suse.cz
- return information that "starting TLS" failed (#246397)
- 2.15.1
* Mon Dec 18 2006 jsuchome@suse.cz
- ask attribute for 'usage' flag (required by F301179)
- new call for testing password policy support (F301179)
- better debug for referral exceptions
- 2.15.0
* Mon Nov  6 2006 jsuchome@suse.cz
- fixed html documentation header
- new version for new product
- 2.14.0
* Fri Mar 31 2006 jsuchome@suse.cz
- constructor of LDAPConnection object may throw an exception (#159741)
- 2.13.4
* Thu Mar  9 2006 jsuchome@suse.cz
- BuildRequires: added missing yast2
- 2.13.3
* Mon Feb  6 2006 jsuchome@suse.cz
- reduced BuildRequires
- 2.13.2
* Tue Nov 22 2005 jsuchome@suse.cz
- adapted .users and .groups calls to to index maps names
  ("uid"/"cn" attributes)
- added .users_by_uidnumber and .groups.by_gidnumber paths
- 2.13.1
* Fri Oct 21 2005 jsuchome@suse.cz
- fixed failing builds, added some comments to functions
- 2.13.0
* Wed Aug 10 2005 jsuchome@suse.cz
- use warnings, not errors for referral exceptions
- 2.12.2
* Thu Apr 21 2005 jsuchome@suse.cz
- adapted for new interface of new start_tls function (#55844)
- 2.12.1
* Tue Mar 15 2005 jsuchome@suse.cz
- do not call methods from deleted object (#72190)
- 2.12.0
* Mon Aug  9 2004 jsuchome@suse.cz
- LdapServerAccess.pm: function for adding indices and Samba ACL hack
- 2.10.4
* Thu Aug  5 2004 jsuchome@suse.cz
- updated to handle the split of ldapcpplib library
- 2.10.3
* Thu Jul 29 2004 jsuchome@suse.cz
- added LdapServerAccess.pm to provide access to LDAP server module
- yast2 is required
- 2.10.2
* Wed Jul 14 2004 jsuchome@suse.cz
- correctly initialize global values in constructor
- read binary values also for users/groups
- 2.10.1
* Fri Jun 11 2004 jsuchome@suse.cz
- implemented Execute (.ldap.ping) call (#41354)
- 2.10.0
* Mon May 17 2004 jsuchome@suse.cz
- enhanced error logging
- 2.9.15
* Wed May 12 2004 jsuchome@suse.cz
- fix of 'rdn' generating during rename (#40420)
- 2.9.14
* Wed May  5 2004 jsuchome@suse.cz
- do not return error, when no user was found
- 2.9.13
* Thu Apr 22 2004 jsuchome@suse.cz
- 2.9.12
* Wed Apr 21 2004 jsuchome@suse.cz
- enable recursive delete (#39185) and rename (#39193)
* Mon Apr 19 2004 jsuchome@suse.cz
- on error, return also additional message produced by server (#38668)
* Tue Apr 13 2004 jsuchome@suse.cz
- "include_dn" option: DN could be included in a map of each entry
  found by search call (#38821)
- 2.9.11
* Thu Apr  8 2004 jsuchome@suse.cz
- "use_tls" could be passed in initialization call
* Fri Apr  2 2004 jsuchome@suse.cz
- changed license to GPL
- 2.9.10
* Tue Mar 30 2004 jsuchome@suse.cz
- enable TLS support (#37393)
- 2.9.9
* Mon Mar 29 2004 jsuchome@suse.cz
- more on binary values: enable multi valued attributes
  (-> List of Byteblocks)
- 2.9.8
* Thu Mar 25 2004 jsuchome@suse.cz
- fixed adding new entry containing attribute with binary value
- 2.9.7
* Mon Mar 22 2004 jsuchome@suse.cz
- return lowercase attribute names
- inital support for binary values
- 2.9.6
* Fri Mar 19 2004 mvidner@suse.cz
- added AGENT_LIBADD so that agents work from standalone Perl
* Mon Mar 15 2004 jsuchome@suse.cz
- do not change LDAP keys for yast2-users usage
  ("uid" for users and "cn" for groups)
- 2.9.5
* Fri Mar 12 2004 jsuchome@suse.cz
- do not ignore userPassword value
* Wed Mar  3 2004 jsuchome@suse.cz
- configurable member attribute of LDAP groups
- 2.9.4
* Wed Feb 25 2004 jsuchome@suse.cz
- convert string-type values to integers if possible
* Wed Feb 11 2004 jsuchome@suse.cz
- attributes "uid" (for users) and "cn" (for groups) allowed only
  with single value
- change in the rename process: first rename, then change the attributes
- 2.9.3
* Tue Feb 10 2004 jsuchome@suse.cz
- check for integer values and convert then to string
* Tue Feb  3 2004 jsuchome@suse.cz
- updated for new Users module
- change of some structures: use map instead of lists (better search)
- 2.9.2
* Tue Nov 18 2003 jsuchome@suse.cz
- 2.9.1
* Tue Nov 18 2003 jsuchome@suse.cz
- migrated to doxygen
* Fri Oct  3 2003 jsuchome@suse.cz
- attribute 'cn' not returned as 'fullname' any more (but as 'cn')
- 2.9.0
* Tue Sep  2 2003 jsuchome@suse.cz
- do not read value of userPassword attribute (for yast2-users module)
* Mon Sep  1 2003 jsuchome@suse.cz
- added test for object class existence
- 2.8.3
* Tue Aug 12 2003 jsuchome@suse.de
- updated agent documentation
- 2.8.2
* Fri Jul 11 2003 jsuchome@suse.de
- groups are now groupOfUniqueNames
* Wed Jul  2 2003 jsuchome@suse.de
- schema support (reading, queries)
- 2.8.1
* Wed May 28 2003 jsuchome@suse.cz
- Initial version
- Enables generic search/add/modify/delete calls
- Special calls used by yast2-users module
